==> haskell-yesod-form-1.4.9-31-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.9
id: yesod-form-1.4.9-38HE1KKEtEhJhAjIU1uGSd
key: yesod-form-1.4.9-38HE1KKEtEhJhAjIU1uGSd
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish
abi: 722f09a4cdbbdb234cc9244d5dcd5ec6
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.9
data-dir: /usr/share/i386-linux-ghc-8.0.1/yesod-form-1.4.9
hs-libraries: HSyesod-form-1.4.9-38HE1KKEtEhJhAjIU1uGSd
depends:
    aeson-1.0.2.1-FRh8NWzqPiiuj2q5G5H5S
    attoparsec-0.13.1.0-IbZnQWsljer1cy7HS9Csat base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-GSSjipzx4RxJDHwv5DVwLn
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.6-Lw6Qrv3XKz9DVUxp21c7T7
    resourcet-1.1.9-J17FkGhZ2yV57Ehh8hruPC
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.12.1-IfTPKmxy9q586R9DLZkNdx
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    wai-3.2.1.1-9mMHgVB1wYz4uCkr33AuWK
    xss-sanitize-0.3.5.7-Ipx5dPIEDGELvDvXzbAO9a
    yesod-core-1.4.30-Ks2NBoJTgnAC1PoSLbAM7E
    yesod-persistent-1.4.1.1-2BMD3NTCnVq9G6lVlRbmfv
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-form-1.4.10-10-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-form.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-form
version: 1.4.10
id: yesod-form-1.4.10-7xZYr8KcdWODECvHLf62dN
key: yesod-form-1.4.10-7xZYr8KcdWODECvHLf62dN
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Form handling support for Yesod Web Framework
description:
    API docs and the README are available at <http://www.stackage.org/package/yesod-form>.  Third-party packages which you can find useful: <http://hackage.haskell.org/package/yesod-form-richtext yesod-form-richtext> - richtext form fields (currntly it provides only Summernote support).
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Yesod.Form Yesod.Form.Types Yesod.Form.Functions
    Yesod.Form.Bootstrap3 Yesod.Form.Input Yesod.Form.Fields
    Yesod.Form.Jquery Yesod.Form.Nic Yesod.Form.MassInput
    Yesod.Form.I18n.English Yesod.Form.I18n.Portuguese
    Yesod.Form.I18n.Swedish Yesod.Form.I18n.German
    Yesod.Form.I18n.French Yesod.Form.I18n.Norwegian
    Yesod.Form.I18n.Japanese Yesod.Form.I18n.Czech
    Yesod.Form.I18n.Russian Yesod.Form.I18n.Dutch
    Yesod.Form.I18n.Spanish
abi: 9d3dad92de94578d071872c2e0f946ac
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.10
library-dirs: /usr/lib/ghc-8.0.1/site-local/yesod-form-1.4.10
data-dir: /usr/share/i386-linux-ghc-8.0.1/yesod-form-1.4.10
hs-libraries: HSyesod-form-1.4.10-7xZYr8KcdWODECvHLf62dN
depends:
    aeson-1.0.2.1-580HLk2Nlp5BZ0wDg2BMVx
    attoparsec-0.13.1.0-6gEFbI8p8A3LThVdJgpVvH base-4.9.0.0
    blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    blaze-html-0.8.1.3-J9yr8vH3H9ALelvCpTjDjF
    blaze-markup-0.7.1.1-JmLydCOPoKfKgaFgoOctdP
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 data-default-0.7.1.1-ZpKfkXGfJa8c8Q6OFbvrr
    email-validate-2.2.0-KpbeZQw4mb4919LCB8WS5H
    network-uri-2.6.1.0-8yR4gjnzE4eDGhJR7PHfVJ
    persistent-2.6-IW9EjImAw3vJ6wSbFCA7c6
    resourcet-1.1.9-CymaqmR8zCeCrSnerfb4Fa
    semigroups-0.18.2-2lmUSJvrDkM6JBURGRclWz
    shakespeare-2.0.12.1-5TO0z9PSLt7EPkCrYoKv4I
    template-haskell-2.11.0.0 text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ
    time-1.6.0.1 transformers-0.5.2.0
    wai-3.2.1.1-G3x7tNXaUUGBY6K4SzJOAN
    xss-sanitize-0.3.5.7-BwOHwiIVwsFDbDKpYjHzDa
    yesod-core-1.4.31-tuwr0E3PIcCefINtIIL0h
    yesod-persistent-1.4.1.1-HI3AFVvH84qKL2SPPEQDLI
haddock-interfaces: /usr/share/doc/haskell-yesod-form/html/yesod-form.haddock
haddock-html: /usr/share/doc/haskell-yesod-form/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
